@@ -3,11 +3,12 @@ from __future__ import annotations
 from typing import Any, AsyncIterator, Callable
 from uuid import UUID
 
-from fastapi import APIRouter, Depends
+from fastapi import Depends
 from fastapi_users import FastAPIUsers
 from fastapi_users.authentication import AuthenticationBackend, BearerTransport, JWTStrategy
 from fastapi_users.manager import BaseUserManager, UUIDIDMixin
 
+from svc_infra.api.fastapi import DualAPIRouter, dualize_router
 from svc_infra.auth.settings import get_auth_settings
 
 
@@ -17,7 +18,7 @@ def get_fastapi_users(
     user_schema_create: Any,
     user_schema_update: Any,
     auth_prefix: str = "/auth",
-) -> tuple[FastAPIUsers, AuthenticationBackend, APIRouter, APIRouter, Callable]:
+) -> tuple[FastAPIUsers, AuthenticationBackend, DualAPIRouter, DualAPIRouter, Callable]:
     """Factory that wires FastAPI Users with JWT backend and returns routers.
 
     Returns: (fastapi_users, auth_backend, auth_router, users_router)
@@ -55,4 +56,7 @@ def get_fastapi_users(
         user_schema_read, user_schema_create, user_schema_update
     )
 
-    return fastapi_users, auth_backend, auth_router, users_router, get_jwt_strategy
+    dual_auth_router = dualize_router(auth_router)
+    dual_users_router = dualize_router(users_router)
+
+    return fastapi_users, auth_backend, dual_auth_router, dual_users_router, get_jwt_strategy
