@@ -8,6 +8,7 @@ from svc_infra.cli.cmds import (
     register_mongo,
     register_mongo_scaffold,
     register_obs,
+    register_redis,
     register_sql_scaffold,
 )
 from svc_infra.cli.foundation.typer_bootstrap import pre_cli
@@ -15,15 +16,18 @@ from svc_infra.cli.foundation.typer_bootstrap import pre_cli
 app = typer.Typer(no_args_is_help=True, add_completion=False, help=_HELP)
 pre_cli(app)
 
-# sql commands
+# --- sql commands ---
 register_alembic(app)
 register_sql_scaffold(app)
 
-# nosql commands
+# --- nosql commands ---
 register_mongo(app)
 register_mongo_scaffold(app)
 
-# observability commands
+# --- cache commands ---
+register_redis(app)
+
+# -- observability commands ---
 register_obs(app)
 
 
